@@ -21,7 +21,6 @@ module Test.Hspec (
 -- * Types
   Spec
 , Example
-, Pending
 
 -- * Setting expectations
 , module Test.Hspec.Expectations
@@ -30,7 +29,13 @@ module Test.Hspec (
 , describe
 , context
 , it
+, example
 , pending
+, pendingWith
+, before
+, after
+, around
+, parallel
 
 -- * Running a spec
 , hspec
@@ -40,9 +45,11 @@ import           Test.Hspec.Core.Type hiding (describe, it)
 import           Test.Hspec.Runner
 import           Test.Hspec.HUnit ()
 import           Test.Hspec.Expectations
-import           Test.Hspec.Pending
 import qualified Test.Hspec.Core as Core
 
+import           Data.IORef
+import           Control.Applicative
+
 -- $intro
 --
 -- The three functions you'll use the most are 'hspec', 'describe', and 'it'.
@@ -124,5 +131,49 @@ context = describe
 -- > describe "absolute" $ do
 -- >   it "returns a positive number when given a negative number" $
 -- >     absolute (-1) == 1
-it :: Example v => String -> v -> Spec
+it :: Example a => String -> a -> Spec
 it label action = fromSpecList [Core.it label action]
+
+-- | This is a type restricted version of `id`.  It can be used to get better
+-- error messages on type mismatches.
+--
+-- Compare e.g.
+--
+-- > it "exposes some behavior" $ example $ do
+-- >   putStrLn
+--
+-- with
+--
+-- > it "exposes some behavior" $ do
+-- >   putStrLn
+example :: Expectation -> Expectation
+example = id
+
+-- | Run examples of given spec in parallel.
+parallel :: Spec -> Spec
+parallel = mapSpecItem $ \_ r e -> SpecItem True r e
+
+-- | Run a custom action before every spec item.
+before :: IO () -> Spec -> Spec
+before action = mapSpecItem $ \b r e -> SpecItem b r (\params -> action *> e params)
+
+-- | Run a custom action after every spec item.
+after :: IO () -> Spec -> Spec
+after action = mapSpecItem $ \b r e -> SpecItem b r (\params -> e params <* action)
+
+-- | Run a custom action before and/or after every spec item.
+around :: (IO () -> IO ()) -> Spec -> Spec
+around action = mapSpecItem $ \b r e -> SpecItem b r (\params -> wrap (e params))
+  where
+    wrap e = do
+      ref <- newIORef (Fail "")
+      action (e >>= writeIORef ref)
+      readIORef ref
+
+mapSpecItem :: (Bool -> String -> (Params -> IO Result) -> SpecTree) -> Spec -> Spec
+mapSpecItem f = fromSpecList . map go . runSpecM
+  where
+    go :: SpecTree -> SpecTree
+    go spec = case spec of
+      SpecItem b r e -> f b r e
+      SpecGroup d es -> SpecGroup d (map go es)
