@@ -8,6 +8,7 @@ module Test.Hspec.Core (
 -- * A type class for examples
   Example (..)
 , Params (..)
+, Progress
 , Result (..)
 
 -- * A writer monad for constructing specs
@@ -27,15 +28,12 @@ module Test.Hspec.Core (
 , hspecX
 , hHspec
 , hspec
-, Pending
-, pending
 ) where
 
 import           Control.Applicative
 import           System.IO (Handle)
 
 import           Test.Hspec.Core.Type hiding (Spec)
-import qualified Test.Hspec.Pending as Pending
 import qualified Test.Hspec.Runner as Runner
 import           Test.Hspec.Runner (Summary(..), Config(..), defaultConfig)
 
@@ -56,17 +54,10 @@ hspecB spec = (== 0) . summaryFailures <$> hspecWith defaultConfig spec
 
 {-# DEPRECATED hHspec "use `Test.Hspec.Runner.hspecWith` instead" #-} -- since 1.4.0
 hHspec :: Handle -> [SpecTree] -> IO Summary
-hHspec h = hspecWith defaultConfig {configHandle = h}
+hHspec h = hspecWith defaultConfig {configHandle = Left h}
 
 {-# DEPRECATED Spec "use `SpecTree` instead" #-}                      -- since 1.4.0
 type Spec = SpecTree
 
 {-# DEPRECATED Specs "use `[SpecTree]` instead" #-}                   -- since 1.4.0
 type Specs = [SpecTree]
-
-{-# DEPRECATED pending "use `Test.Hspec.pending` instead" #-}         -- since 1.4.0
-pending :: String -> Pending
-pending = Pending.pending
-
-{-# DEPRECATED Pending "use `Test.Hspec.Pending` instead" #-}         -- since 1.4.0
-type Pending = Pending.Pending
